@@ -18,7 +18,7 @@ class ReadOnlyDataset:
         self._meta_file = os.path.join(data_dir, "{}.meta".format(data_name))
         self._data_open = False
         self._data_handle = None
-        self._meta, self._index = self._read_meta_index()
+        self.record_type, self._index = self._read_meta_index()
         self._record_count = len(self._index) - 1
         assert self._record_count >= 0, "Dataset length < 0. please make sure close dataset after all records written"
         self._cursor = 0
@@ -48,7 +48,7 @@ class ReadOnlyDataset:
         data = define.FeatureMap()
         data.ParseFromString(buffer)
         self._cursor += 1
-        return record.RecordDefine.decode(data, self._meta)
+        return record.RecordDefine.decode(data, self.record_type)
 
     def __getitem__(self, idx):
         idx = int(idx)
@@ -62,7 +62,7 @@ class ReadOnlyDataset:
         data = define.FeatureMap()
         data.ParseFromString(buffer)
         self._cursor = idx
-        return record.RecordDefine.decode(data, self._meta)
+        return record.RecordDefine.decode(data, self.record_type)
 
     def __next__(self):
         return self.next()
